byte-pysqlite
=============

.. image:: https://img.shields.io/pypi/v/byte-pysqlite.svg?style=flat-square
   :target: https://pypi.python.org/pypi/byte-pysqlite

.. image:: https://img.shields.io/travis/fuzeman/byte-pysqlite.svg?style=flat-square
   :target: https://travis-ci.org/fuzeman/byte-pysqlite

.. image:: https://img.shields.io/codeclimate/github/fuzeman/byte-pysqlite.svg?style=flat-square
   :target: https://codeclimate.com/github/fuzeman/byte-pysqlite

.. image:: https://img.shields.io/coveralls/fuzeman/byte-pysqlite/master.svg?style=flat-square
   :target: https://coveralls.io/github/fuzeman/byte-pysqlite

PySQLite executor for `byte <https://github.com/fuzeman/byte>`_.

**Supported Platforms:**

- **Python:** 2.7

**Requirements:**

- **byte:** 0.3.0+
- **byte-sqlite:** 0.3.0+
- **pysqlite:** 2.8.0+

Development
-----------

**Status:** Alpha

Usable, but many features are still in development.
